@@ -1,5 +1,5 @@
 use bevy::prelude::*;
-use bevy_ecs_tilemap::{TilemapLabel, TilemapStage};
+use bevy_ecs_tilemap::TilemapStage;
 
 #[derive(Debug, Clone, PartialEq, Eq, Hash, StageLabel)]
 pub struct TilesetMapStage;
@@ -36,7 +36,7 @@ impl Plugin for TilesetMapPlugin {
 				TilemapStage,
 				crate::auto::on_change_auto_tile
 					.label(TilesetMapLabel::UpdateAutoTiles)
-					.before(TilemapLabel::UpdateChunkVisibility),
+					.before(bevy_ecs_tilemap::TilemapLabel::UpdateChunkVisibility),
 			);
 	}
 }
